@@ -15,8 +15,11 @@ npx @rmw/md-include .markdown.json
 
 cargo set-version --bump patch
 
+version=$(cat Cargo.toml|grep "^version"|awk -F\" '{print $2}')
+
 git add -u
-git commit -m dist
+git commit -m "v$version"
+git tag v$version
 git push
 
 cargo +nightly publish
