@@ -6,30 +6,37 @@ pub mod tx;
 
 pub use ffi::mdbx_version;
 
+#[macro_export]
+macro_rules! run {
+  ($expr:expr) => {
+    unsafe { ffi::MDBX_error_t($expr) }
+  };
+}
+
 #[macro_export]
 macro_rules! ok_err {
-    ($expr:expr) => {
-        unsafe { crate::err::err(ffi::MDBX_error_t($expr)) }
-    };
+  ($expr:expr) => {
+    crate::err::err(crate::run!($expr))
+  };
 }
 
 #[macro_export]
 macro_rules! ok {
-    ($expr:expr) => {
-        crate::ok_err!($expr)?
-    };
+  ($expr:expr) => {
+    crate::ok_err!($expr)?
+  };
 }
 
 #[macro_export]
 macro_rules! ok_or_log {
-    ($expr:expr) => {
-        match crate::ok_err!($expr) {
-            Err(err) => {
-                log::error!("{}", err)
-            }
-            _ => {}
-        }
-    };
+  ($expr:expr) => {
+    match crate::ok_err!($expr) {
+      Err(err) => {
+        log::error!("{}", err)
+      }
+      _ => {}
+    }
+  };
 }
 
 #[macro_export]
@@ -59,7 +66,7 @@ macro_rules! Db {
     paste::paste! {
       #[allow(non_snake_case)]
       #[ctor::ctor]
-      fn [<init_$name>]() {
+      fn [<_init$name>]() {
         lazy_static::initialize(&$name);
       }
     }
